==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Circle/CircleTPR/ts/CircleTPR_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>ArcTPR</name>
    <message>
        <source>Choose line, arc, circle or ellipse</source>
        <translation type="vanished">Izberi črto, lok, krog ali elipso</translation>
    </message>
    <message>
        <source>Point on arc</source>
        <translation type="vanished">Točka na loku</translation>
    </message>
    <message>
        <source>Choose solution</source>
        <translation type="vanished">Izberite rešitev</translation>
    </message>
    <message>
        <source>No solution</source>
        <translation type="vanished">Ni rešitve</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation type="vanished">Polmer:</translation>
    </message>
    <message>
        <source>&amp;Tangent, Point, Radius</source>
        <translation type="vanished">&amp;Tangenta, Točka, Polmer</translation>
    </message>
    <message>
        <source>Draw arc tangential to entity, through point with radius</source>
        <translation type="vanished">Nariši lok tangencialno na entiteto, skozi točko s polmerom</translation>
    </message>
</context>
<context>
    <name>Circle2TP</name>
    <message>
        <source>First line, arc or circle</source>
        <translation type="obsolete">Prva črta, lok ali krog</translation>
    </message>
    <message>
        <source>Second line, arc or circle</source>
        <translation type="obsolete">Druga črta, lok ali krog</translation>
    </message>
    <message>
        <source>Point on circle line</source>
        <translation type="obsolete">Točka na črti kroga</translation>
    </message>
    <message>
        <source>Choose solution</source>
        <translation type="obsolete">Izberite rešitev</translation>
    </message>
    <message>
        <source>No solution</source>
        <translation type="obsolete">Ni rešitve</translation>
    </message>
    <message>
        <source>Point, 2 Tan&amp;gents</source>
        <translation type="obsolete">Točka, 2 Tan&amp;genti</translation>
    </message>
    <message>
        <source>Draw circle tangential to two entities, through point</source>
        <translation type="obsolete">Nariši krog tangencialno na dve entiteti, skozi točko</translation>
    </message>
</context>
<context>
    <name>CircleTPR</name>
    <message>
        <location filename="../CircleTPR.js" line="+39"/>
        <source>Point on circle</source>
        <translation>Točka na krogu</translation>
    </message>
    <message>
        <location filename="../CircleTPRInit.js" line="+2"/>
        <source>&amp;Tangent, Point, Radius</source>
        <translation>&amp;Tangenta, Točka, Polmer</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw circle tangential to entity, through point with radius</source>
        <translation>Nariši krog tangencialno na entiteto, skozi točko z polmerom</translation>
    </message>
    <message>
        <location filename="../CircleTPR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>Polmer:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Circle/CircleTPR/ts/CircleTPR_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>ArcTPR</name>
    <message>
        <source>Choose line, arc, circle or ellipse</source>
        <translation type="vanished">Izberi črto, lok, krog ali elipso</translation>
    </message>
    <message>
        <source>Point on arc</source>
        <translation type="vanished">Točka na loku</translation>
    </message>
    <message>
        <source>Choose solution</source>
        <translation type="vanished">Izberite rešitev</translation>
    </message>
    <message>
        <source>No solution</source>
        <translation type="vanished">Ni rešitve</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation type="vanished">Polmer:</translation>
    </message>
    <message>
        <source>&amp;Tangent, Point, Radius</source>
        <translation type="vanished">&amp;Tangenta, Točka, Polmer</translation>
    </message>
    <message>
        <source>Draw arc tangential to entity, through point with radius</source>
        <translation type="vanished">Nariši lok tangencialno na entiteto, skozi točko s polmerom</translation>
    </message>
</context>
<context>
    <name>Circle2TP</name>
    <message>
        <source>First line, arc or circle</source>
        <translation type="obsolete">Prva črta, lok ali krog</translation>
    </message>
    <message>
        <source>Second line, arc or circle</source>
        <translation type="obsolete">Druga črta, lok ali krog</translation>
    </message>
    <message>
        <source>Point on circle line</source>
        <translation type="obsolete">Točka na črti kroga</translation>
    </message>
    <message>
        <source>Choose solution</source>
        <translation type="obsolete">Izberite rešitev</translation>
    </message>
    <message>
        <source>No solution</source>
        <translation type="obsolete">Ni rešitve</translation>
    </message>
    <message>
        <source>Point, 2 Tan&amp;gents</source>
        <translation type="obsolete">Točka, 2 Tan&amp;genti</translation>
    </message>
    <message>
        <source>Draw circle tangential to two entities, through point</source>
        <translation type="obsolete">Nariši krog tangencialno na dve entiteti, skozi točko</translation>
    </message>
</context>
<context>
    <name>CircleTPR</name>
    <message>
        <location filename="../CircleTPR.js" line="+39"/>
        <source>Point on circle</source>
        <translation>Točka na krogu</translation>
    </message>
    <message>
        <location filename="../CircleTPRInit.js" line="+2"/>
        <source>&amp;Tangent, Point, Radius</source>
        <translation>&amp;Tangenta, Točka, Polmer</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw circle tangential to entity, through point with radius</source>
        <translation>Nariši krog tangencialno na entiteto, skozi točko s polmerom</translation>
    </message>
    <message>
        <location filename="../CircleTPR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>Polmer:</translation>
    </message>
</context>
</TS>
